@@ -1,5 +1,4 @@
-require 'backports'
-require_relative 'spec_helper'
+require 'spec_helper'
 
 describe Sinatra::Namespace do
   verbs = [:get, :head, :post, :put, :delete, :options]
@@ -44,7 +43,7 @@ describe Sinatra::Namespace do
         it 'accepts the path as a regular expression' do
           namespace('/foo') { send(verb, /\/\d\d/) { 'bar' }}
           send(verb, '/foo/12').should be_ok
-          body.should == 'bar' unless verb == :head
+          body.should eq 'bar' unless verb == :head
           send(verb, '/foo/123').should_not be_ok
         end
       end
@@ -119,14 +118,14 @@ describe Sinatra::Namespace do
           ran = false
           namespace('/foo') { before { ran = true }}
           send(verb, '/foo')
-          ran.should be_true
+          ran.should be true
         end
 
         specify 'are not triggered for a different namespace' do
           ran = false
           namespace('/foo') { before { ran = true }}
           send(verb, '/fox')
-          ran.should be_false
+          ran.should be false
         end
       end
 
@@ -135,14 +134,14 @@ describe Sinatra::Namespace do
           ran = false
           namespace('/foo') { after { ran = true }}
           send(verb, '/foo')
-          ran.should be_true
+          ran.should be true
         end
 
         specify 'are not triggered for a different namespace' do
           ran = false
           namespace('/foo') { after { ran = true }}
           send(verb, '/fox')
-          ran.should be_false
+          ran.should be false
         end
       end
 
@@ -177,13 +176,13 @@ describe Sinatra::Namespace do
               send(verb, '/*') { 'ok' }
             end
             send(verb, '/foo', {}, 'HTTP_HOST' => 'example.org', 'HTTP_ACCEPT' => 'text/plain')
-            ran.should be_false
+            ran.should be false
             send(verb, '/foo', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/html')
-            ran.should be_false
+            ran.should be false
             send(verb, '/bar', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/plain')
-            ran.should be_false
+            ran.should be false
             send(verb, '/foo', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/plain')
-            ran.should be_true
+            ran.should be true
           end
 
           specify 'are accepted in the after-filter' do
@@ -193,13 +192,13 @@ describe Sinatra::Namespace do
               send(verb, '/*') { 'ok' }
             end
             send(verb, '/foo', {}, 'HTTP_HOST' => 'example.org', 'HTTP_ACCEPT' => 'text/plain')
-            ran.should be_false
+            ran.should be false
             send(verb, '/foo', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/html')
-            ran.should be_false
+            ran.should be false
             send(verb, '/bar', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/plain')
-            ran.should be_false
+            ran.should be false
             send(verb, '/foo', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/plain')
-            ran.should be_true
+            ran.should be true
           end
         end
 
@@ -232,9 +231,9 @@ describe Sinatra::Namespace do
               send(verb) { 'ok' }
             end
             send(verb, '/foo', {}, 'HTTP_HOST' => 'example.org')
-            ran.should be_false
+            ran.should be false
             send(verb, '/foo', {}, 'HTTP_HOST' => 'example.com')
-            ran.should be_true
+            ran.should be true
           end
 
           specify 'are accepted in the route definition' do
@@ -253,11 +252,11 @@ describe Sinatra::Namespace do
                 send(verb) { 'ok' }
               end
               send(verb, '/', {}, 'HTTP_HOST' => 'example.org', 'HTTP_ACCEPT' => 'text/plain')
-              ran.should be_false
+              ran.should be false
               send(verb, '/', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/html')
-              ran.should be_false
+              ran.should be false
               send(verb, '/', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/plain')
-              ran.should be_true
+              ran.should be true
             end
 
             specify 'are accepted in the filters' do
@@ -267,13 +266,13 @@ describe Sinatra::Namespace do
                 send(verb, '/*') { 'ok' }
               end
               send(verb, '/foo', {}, 'HTTP_HOST' => 'example.org', 'HTTP_ACCEPT' => 'text/plain')
-              ran.should be_false
+              ran.should be false
               send(verb, '/foo', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/html')
-              ran.should be_false
+              ran.should be false
               send(verb, '/far', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/plain')
-              ran.should be_false
+              ran.should be false
               send(verb, '/foo', {}, 'HTTP_HOST' => 'example.com', 'HTTP_ACCEPT' => 'text/plain')
-              ran.should be_true
+              ran.should be true
             end
           end
         end
@@ -479,24 +478,24 @@ describe Sinatra::Namespace do
           namespace('/de') do
             not_found { 'nicht gefunden' }
           end
-          send(verb, '/foo').status.should == 404
-          last_response.body.should_not    == 'nicht gefunden' unless verb == :head
-          get('/en/foo').status.should     == 404
-          last_response.body.should_not    == 'nicht gefunden' unless verb == :head
-          get('/de/foo').status.should     == 404
-          last_response.body.should        == 'nicht gefunden' unless verb == :head
+          send(verb, '/foo').status.should eq 404
+          last_response.body.should_not    eq 'nicht gefunden' unless verb == :head
+          get('/en/foo').status.should     eq 404
+          last_response.body.should_not    eq 'nicht gefunden' unless verb == :head
+          get('/de/foo').status.should     eq 404
+          last_response.body.should        eq 'nicht gefunden' unless verb == :head
         end
 
         it 'can be customized for specific error codes' do
           namespace('/de') do
             error(404) { 'nicht gefunden' }
           end
-          send(verb, '/foo').status.should == 404
-          last_response.body.should_not    == 'nicht gefunden' unless verb == :head
-          get('/en/foo').status.should     == 404
-          last_response.body.should_not    == 'nicht gefunden' unless verb == :head
-          get('/de/foo').status.should     == 404
-          last_response.body.should        == 'nicht gefunden' unless verb == :head
+          send(verb, '/foo').status.should eq 404
+          last_response.body.should_not    eq 'nicht gefunden' unless verb == :head
+          get('/en/foo').status.should     eq 404
+          last_response.body.should_not    eq 'nicht gefunden' unless verb == :head
+          get('/de/foo').status.should     eq 404
+          last_response.body.should        eq 'nicht gefunden' unless verb == :head
         end
 
         it 'falls back to the handler defined in the base app' do
@@ -508,12 +507,12 @@ describe Sinatra::Namespace do
               error(404) { 'nicht gefunden' }
             end
           end
-          send(verb, '/foo').status.should == 404
-          last_response.body.should        == 'not found...' unless verb == :head
-          get('/en/foo').status.should     == 404
-          last_response.body.should        == 'not found...' unless verb == :head
-          get('/de/foo').status.should     == 404
-          last_response.body.should        == 'nicht gefunden' unless verb == :head
+          send(verb, '/foo').status.should eq 404
+          last_response.body.should        eq 'not found...' unless verb == :head
+          get('/en/foo').status.should     eq 404
+          last_response.body.should        eq 'not found...' unless verb == :head
+          get('/de/foo').status.should     eq 404
+          last_response.body.should        eq 'nicht gefunden' unless verb == :head
         end
 
         it 'can be customized for specific Exception classes' do
@@ -543,10 +542,28 @@ describe Sinatra::Namespace do
               end
             end
           end
-          get('/en/foo').status.should     == 401
-          last_response.body.should        == 'auth failed' unless verb == :head
-          get('/de/foo').status.should     == 406
-          last_response.body.should        == 'methode nicht erlaubt' unless verb == :head
+          get('/en/foo').status.should     eq 401
+          last_response.body.should        eq 'auth failed' unless verb == :head
+          get('/de/foo').status.should     eq 406
+          last_response.body.should        eq 'methode nicht erlaubt' unless verb == :head
+        end
+
+        it "allows custom error handlers when namespace is declared as /en/:id. Issue #119" do
+          mock_app {
+            class CError < StandardError;
+            end
+
+            error { raise "should not come here" }
+
+            namespace('/en/:id') do
+              error(CError) { 201 }
+              get '/?' do
+                raise CError
+              end
+            end
+          }
+
+          get('/en/1').status.should == 201
         end
       end
 
@@ -561,8 +578,8 @@ describe Sinatra::Namespace do
               end
             end
 
-            send(verb, '/').body.should == 'hi'
-            send(verb, '/foo').body.should == 'hi'
+            send(verb, '/').body.should eq 'hi'
+            send(verb, '/foo').body.should eq 'hi'
           end
 
           specify 'can be nested' do
@@ -575,8 +592,8 @@ describe Sinatra::Namespace do
               end
             end
 
-            send(verb, '/').body.should == 'hi'
-            send(verb, '/foo').body.should == 'ho'
+            send(verb, '/').body.should eq 'hi'
+            send(verb, '/foo').body.should eq 'ho'
           end
 
           specify 'can use a custom views directory' do
@@ -589,8 +606,8 @@ describe Sinatra::Namespace do
               end
             end
 
-            send(verb, '/').body.should == "hi\n"
-            send(verb, '/foo').body.should == "ho\n"
+            send(verb, '/').body.should eq "hi\n"
+            send(verb, '/foo').body.should eq "ho\n"
           end
 
           specify 'default to the base app\'s layout' do
@@ -604,8 +621,8 @@ describe Sinatra::Namespace do
               end
             end
 
-            send(verb, '/').body.should == 'he said: hi'
-            send(verb, '/foo').body.should == 'he said: ho'
+            send(verb, '/').body.should eq 'he said: hi'
+            send(verb, '/foo').body.should eq 'he said: ho'
           end
 
           specify 'can define nested layouts' do
@@ -619,8 +636,8 @@ describe Sinatra::Namespace do
               end
             end
 
-            send(verb, '/').body.should == 'Hello World!'
-            send(verb, '/foo').body.should == 'Hi World!'
+            send(verb, '/').body.should eq 'Hello World!'
+            send(verb, '/foo').body.should eq 'Hi World!'
           end
         end
       end
@@ -634,7 +651,7 @@ describe Sinatra::Namespace do
               value = foo
             end
           end
-          value.should == 42
+          value.should eq 42
         end
 
         specify 'can be registered within a namespace' do
@@ -647,8 +664,8 @@ describe Sinatra::Namespace do
             end
             b = views
           end
-          a.should == 'CUSTOM!!!'
-          b.should_not == 'CUSTOM!!!'
+          a.should eq 'CUSTOM!!!'
+          b.should_not eq 'CUSTOM!!!'
         end
 
         specify 'trigger the route_added hook' do
@@ -664,7 +681,7 @@ describe Sinatra::Namespace do
             end
             get('/bar') { }
           end
-          route[1].should == '/foo'
+          route[1].should eq '/foo'
         end
 
         specify 'prevent app-global settings from being changed' do
@@ -673,4 +690,52 @@ describe Sinatra::Namespace do
       end
     end
   end
+
+  describe 'settings' do
+    it 'provides access to top-level settings' do
+      mock_app do
+        set :foo, 'ok'
+
+        namespace '/foo' do
+          get '/bar' do
+            settings.foo
+          end
+        end
+      end
+
+      get('/foo/bar').status.should == 200
+      last_response.body.should == 'ok'
+    end
+
+    it 'uses some repro' do
+      mock_app do
+        set :foo, 42
+
+        namespace '/foo' do
+          get '/bar' do
+            #settings.respond_to?(:foo).to_s
+            settings.foo.to_s
+          end
+        end
+      end
+
+      get('/foo/bar').status.should == 200
+      last_response.body.should == '42'
+    end
+
+    it 'allows checking setting existence with respond_to?' do
+      mock_app do
+        set :foo, 42
+
+        namespace '/foo' do
+          get '/bar' do
+            settings.respond_to?(:foo).to_s
+          end
+        end
+      end
+
+      get('/foo/bar').status.should == 200
+      last_response.body.should == 'true'
+    end
+  end
 end
